<template>
  <a-card :bordered="false">

    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :xl="4" :lg="7" :md="8" :sm="24">
            <a-form-item label="刀具编号">
              <a-input placeholder="请输入刀具编号" v-model="queryParam.toolId"></a-input>
            </a-form-item>
          </a-col>
          <a-col :xl="4" :lg="7" :md="8" :sm="24">
            <a-form-item label="刃磨结果">
              <a-input placeholder="请输入刃磨结果" v-model="queryParam.sharpeningResult"></a-input>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="刃磨时间">
              <a-range-picker v-model="queryParam.sharpeningTime" @change="onToolSharpeningDateChange" format="YYYY-MM-DD" value-format="YYYY-MM-DD" />
            </a-form-item>
          </a-col>
          <a-col :xl="4" :lg="7" :md="8" :sm="24">
            <span style="float: left;overflow: hidden;" class="table-page-search-submitButtons">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button type="info" @click="searchReset" icon="reload" style="margin-left: 8px">重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel">
            <a-icon type="delete" />
            删除
          </a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作
          <a-icon type="down" />
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a
        style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        class="j-table-force-nowrap"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        @change="handleTableChange">

        <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)">编辑</a>

          <a-divider type="vertical" />
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down" /></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a @click="handleDetail(record)">详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>

            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>
    <!-- table区域-end -->

    <tools-sharpening-modal ref="modalForm"  @ok="modalFormOk"></tools-sharpening-modal>
  </a-card>
</template>

<script>
import '@/assets/less/TableExpand.less'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import ToolsSharpeningModal from './modules/ToolsSharpeningModal'
import { getAction, putAction, deleteAction } from '../../../api/manage'
export default {
  name: 'ToolSharpeningList',
  mixins: [JeecgListMixin],
  components: {
    ToolsSharpeningModal
  },
  data() {
    return {
      description: '刀具刃磨页面',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key:'rowIndex',
          width:60,
          align:"center",
          customRender:function (t,r,index) {
            return parseInt(index)+1;
          }
        },
        {
          title:'刀具分类',
          align:"center",
          dataIndex: 'paramaTableName_dictText'
        },
        {
          title:'刀具编号',
          align:"center",
          dataIndex: 'toolId'
        },
        // {
        //   title:'刀具名称',
        //   align:"center",
        //   dataIndex: 'typeName'
        // },
        {
          title:'厂家',
          align:"center",
          dataIndex: 'supplierId',
        },
        {
          title:'刃磨时间',
          align:"center",
          dataIndex: 'sharpeningTime'
        },
        {
          title:'刃磨结果及建议',
          align:"center",
          dataIndex: 'sharpeningResult'
        },
        {
          title:'责任人',
          align:"center",
          dataIndex: 'responsiblePerson_dictText'
        },

        {
          title:'创建人',
          align:"center",
          dataIndex: 'createBy'
        },

        {
          title:'创建时间',
          align:"center",
          dataIndex: 'createTime'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align:"center",
          fixed:"right",
          width:147,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: "/tms/toolSharpening/listToolSharpening",
        add: "/tms/toolSharpening/add",
        delete: "/tms/toolSharpening/delete",
        edit: "/tms/toolSharpening/edit",
        deleteBatch: "/tms/toolSharpening/deleteBatch",
        exportXlsUrl: "/tms/toolSharpening/exportXls",
        importExcelUrl: "tms/toolSharpening/importExcel",
      },
    }
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  methods: {
        onToolSharpeningDateChange: function(value, dateString) {
          this.queryParam.sharpeningTimeBegin = dateString[0]
          this.queryParam.sharpeningTimeEnd = dateString[1]
        },

  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>